==> kmymoney_5.2.1.orig.tar.xz: kmymoney-5.2.1/kmymoney/plugins/views/reports/reportsview.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "asoliverez@gmail.com,lukasz.wojnilowicz@gmail.com",
                "Name": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ca@valencia]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ca]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[cs]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[de]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[en_GB]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[eo]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[es]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[et]": "Alvaro Soliverez, Łukasz Wojniłowicz",
                "Name[eu]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[fi]": "Alvaro Soliverez, Łukasz Wojniłowicz",
                "Name[fr]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[gl]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ia]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[it]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ka]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ko]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[nb]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[nl]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[pl]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[pt]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[pt_BR]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ru]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[sk]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[sl]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[sv]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[tr]": "Alvaro Soliverez, Łukasz Wojniłowicz",
                "Name[uk]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[x-test]": "xxAlvaro Soliverez,Łukasz Wojniłowiczxx",
                "Name[zh_CN]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[zh_TW]": "Alvaro Soliverez、Łukasz Wojniłowicz"
            }
        ],
        "Description": "Adds reports view to KMyMoney",
        "Description[ca@valencia]": "Afig la vista dels informes a KMyMoney",
        "Description[ca]": "Afegeix la vista dels informes al KMyMoney",
        "Description[en_GB]": "Adds reports view to KMyMoney",
        "Description[eo]": "Aldonas raportan vidon al KMyMoney",
        "Description[es]": "Añade una vista de informes a KMyMoney",
        "Description[et]": "KMyMoney aruandevaade",
        "Description[eu]": "Txosten ikuspegia gehitzen dio KMyMoneyri",
        "Description[fi]": "Lisää KMyMoneyyn raporttinäkymän",
        "Description[fr]": "Ajoute la vue Rapports à KMyMoney",
        "Description[gl]": "Engade unha vista de informes a KMyMoney",
        "Description[ia]": "Adde vista de reportos a KMyMoney",
        "Description[it]": "Aggiunge la vista dei report a KMyMoney",
        "Description[ka]": "KMyMoney-ში ანგარიშის ხედების დამატება",
        "Description[ko]": "KMyMoney에 보고서 보기 추가",
        "Description[nb]": "Legger til rapportvisning i KMyMoney",
        "Description[nl]": "Voegt weergave van rapporten toe aan KMyMoney",
        "Description[pl]": "Dodaje widok sprawozdań do KMyMoney",
        "Description[pt]": "Adiciona a área de relatórios ao KMyMoney",
        "Description[pt_BR]": "Adiciona área de relatórios no KMyMoney",
        "Description[ru]": "Добавляет в KMyMoney представление отчётов",
        "Description[sk]": "Pridá pohľad výpisov do KMyMoney",
        "Description[sl]": "Doda pogled poročil v KMyMoney",
        "Description[sv]": "Lägger till rapportvy i KMyMoney",
        "Description[tr]": "K Param’a raporlar görünümü ekleyin",
        "Description[uk]": "Панель звітів у KMyMoney",
        "Description[x-test]": "xxAdds reports view to KMyMoneyxx",
        "Description[zh_CN]": "为 KMyMoney 添加报告视图",
        "Description[zh_TW]": "提供回報檢視給 KMyMoney",
        "EnabledByDefault": true,
        "Icon": "report",
        "Id": "reportsview",
        "License": "GPL",
        "Name": "Reports view",
        "Name[ca@valencia]": "Vista dels informes",
        "Name[ca]": "Vista dels informes",
        "Name[de]": "Berichtsansicht",
        "Name[en_GB]": "Reports view",
        "Name[eo]": "Raportoj-vido",
        "Name[es]": "Vista de informes",
        "Name[et]": "Aruandevaade",
        "Name[eu]": "Txosten ikuspegia",
        "Name[fi]": "Raporttinäkymä",
        "Name[fr]": "Vue Rapports",
        "Name[gl]": "Vista de informes",
        "Name[ia]": "Vista de Reportos",
        "Name[it]": "Vista dei report",
        "Name[ka]": "ანგარიშების ხედი",
        "Name[ko]": "보고서 보기",
        "Name[nb]": "Rapportvisning",
        "Name[nl]": "Rapportenweergave",
        "Name[pl]": "Widok sprawozdań",
        "Name[pt]": "Área de relatórios",
        "Name[pt_BR]": "Área de relatórios",
        "Name[ru]": "Представление отчётов",
        "Name[sk]": "Pohľad výpisov",
        "Name[sl]": "Pogled poročil",
        "Name[sv]": "Rapportvy",
        "Name[tr]": "Rapor Görünümü",
        "Name[uk]": "Перегляд звітів",
        "Name[x-test]": "xxReports viewxx",
        "Name[zh_CN]": "报表视图",
        "Name[zh_TW]": "報告檢視",
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    },
    "X-KDE-ConfigModule": "kmymoney_plugins/kcms/kcm_reportsview"
}

==> kmymoney_5.2.2.orig.tar.xz: kmymoney-5.2.2/kmymoney/plugins/views/reports/reportsview.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "asoliverez@gmail.com,lukasz.wojnilowicz@gmail.com",
                "Name": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ar]": "ألفارو سوليفيريز، لوكاس فوينيلوفيتش",
                "Name[ca@valencia]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ca]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[cs]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[de]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[en_GB]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[eo]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[es]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[et]": "Alvaro Soliverez, Łukasz Wojniłowicz",
                "Name[eu]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[fi]": "Alvaro Soliverez, Łukasz Wojniłowicz",
                "Name[fr]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[gl]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ia]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[it]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ka]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ko]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[nb]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[nl]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[pl]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[pt]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[pt_BR]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ru]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[sk]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[sl]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[sv]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[tr]": "Alvaro Soliverez, Łukasz Wojniłowicz",
                "Name[uk]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[zh_CN]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[zh_TW]": "Alvaro Soliverez、Łukasz Wojniłowicz"
            }
        ],
        "Description": "Adds reports view to KMyMoney",
        "Description[ar]": "أضف عرض التقارير إلى «أموالك» أموالك",
        "Description[ca@valencia]": "Afig la vista dels informes a KMyMoney",
        "Description[ca]": "Afegeix la vista dels informes al KMyMoney",
        "Description[en_GB]": "Adds reports view to KMyMoney",
        "Description[eo]": "Aldonas raportan vidon al KMyMoney",
        "Description[es]": "Añade una vista de informes a KMyMoney",
        "Description[et]": "KMyMoney aruandevaade",
        "Description[eu]": "Txosten ikuspegia gehitzen dio KMyMoneyri",
        "Description[fi]": "Lisää KMyMoneyyn raporttinäkymän",
        "Description[fr]": "Ajoute la vue Rapports à KMyMoney",
        "Description[gl]": "Engade unha vista de informes a KMyMoney",
        "Description[ia]": "Adde vista de reportos a KMyMoney",
        "Description[it]": "Aggiunge la vista dei report a KMyMoney",
        "Description[ka]": "KMyMoney-ში ანგარიშის ხედების დამატება",
        "Description[ko]": "KMyMoney에 보고서 보기 추가",
        "Description[nb]": "Legger til rapportvisning i KMyMoney",
        "Description[nl]": "Voegt weergave van rapporten toe aan KMyMoney",
        "Description[pl]": "Dodaje widok sprawozdań do KMyMoney",
        "Description[pt]": "Adiciona a área de relatórios ao KMyMoney",
        "Description[pt_BR]": "Adiciona área de relatórios no KMyMoney",
        "Description[ru]": "Добавляет в KMyMoney представление отчётов",
        "Description[sk]": "Pridá pohľad výpisov do KMyMoney",
        "Description[sl]": "Doda pogled poročil v KMyMoney",
        "Description[sv]": "Lägger till rapportvy i KMyMoney",
        "Description[tr]": "K Param’a raporlar görünümü ekleyin",
        "Description[uk]": "Панель звітів у KMyMoney",
        "Description[zh_CN]": "为 KMyMoney 添加报告视图",
        "Description[zh_TW]": "提供回報檢視給 KMyMoney",
        "EnabledByDefault": true,
        "Icon": "report",
        "Id": "reportsview",
        "License": "GPL",
        "Name": "Reports view",
        "Name[ar]": "عرض التقارير",
        "Name[ca@valencia]": "Vista dels informes",
        "Name[ca]": "Vista dels informes",
        "Name[de]": "Berichtsansicht",
        "Name[en_GB]": "Reports view",
        "Name[eo]": "Raportoj-vido",
        "Name[es]": "Vista de informes",
        "Name[et]": "Aruandevaade",
        "Name[eu]": "Txosten ikuspegia",
        "Name[fi]": "Raporttinäkymä",
        "Name[fr]": "Vue Rapports",
        "Name[gl]": "Vista de informes",
        "Name[ia]": "Vista de Reportos",
        "Name[it]": "Vista dei report",
        "Name[ka]": "ანგარიშების ხედი",
        "Name[ko]": "보고서 보기",
        "Name[nb]": "Rapportvisning",
        "Name[nl]": "Rapportenweergave",
        "Name[pl]": "Widok sprawozdań",
        "Name[pt]": "Área de relatórios",
        "Name[pt_BR]": "Área de relatórios",
        "Name[ru]": "Представление отчётов",
        "Name[sk]": "Pohľad výpisov",
        "Name[sl]": "Pogled poročil",
        "Name[sv]": "Rapportvy",
        "Name[tr]": "Rapor Görünümü",
        "Name[uk]": "Перегляд звітів",
        "Name[zh_CN]": "报表视图",
        "Name[zh_TW]": "報告檢視",
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    },
    "X-KDE-ConfigModule": "kmymoney_plugins/kcms/kcm_reportsview"
}
